|PyPI| |Test| |Gitter| |DOI| |binder|

.. |PyPI| image:: https://img.shields.io/pypi/v/folium.svg
    :target: https://pypi.org/project/folium
    :alt: PyPI Package

.. |Test| image:: https://github.com/python-visualization/folium/actions/workflows/test_code.yml/badge.svg
    :target: https://github.com/python-visualization/folium/actions/workflows/test_code.yml
    :alt: Code tests

.. |Gitter| image:: https://badges.gitter.im/python-visualization/folium.svg
    :target: https://gitter.im/python-visualization/folium
    :alt: Gitter

.. |DOI| image:: https://zenodo.org/badge/18669/python-visualization/folium.svg
   :target: https://zenodo.org/badge/latestdoi/18669/python-visualization/folium
   :alt: DOI

.. |binder| image:: https://mybinder.org/badge_logo.svg
 :target: https://mybinder.org/v2/gh/python-visualization/folium/main?filepath=examples

folium
======

.. image:: https://github.com/python-visualization/folium/blob/main/docs/_static/folium_logo.png
   :height: 100px


Python Data, Leaflet.js Maps
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

`folium` builds on the data wrangling strengths of the Python ecosystem and the
mapping strengths of the Leaflet.js library. Manipulate your data in Python,
then visualize it in a Leaflet map via `folium`.

Installation
------------

.. code:: bash

    $ pip install folium

or

.. code:: bash

    $ conda install -c conda-forge folium

Documentation
-------------

https://python-visualization.github.io/folium/latest/


Contributing
------------

We love contributions!  folium is open source, built on open source,
and we'd love to have you hang out in our community.

See `our complete contributor's guide <https://github.com/python-visualization/folium/blob/main/.github/CONTRIBUTING.md>`_ for more info.


Changelog
---------

Check the `changelog <https://raw.githubusercontent.com/python-visualization/folium/main/CHANGES.txt>`_ for a detailed list of the latest changes.


Packages and plugins
--------------------

Packages:

- https://github.com/geopandas/xyzservices: a repository of raster basemap tilesets.
- https://github.com/randyzwitch/streamlit-folium: run folium in a Streamlit app.
- https://github.com/FEMlium/FEMlium: interactive visualization of finite element simulations on geographic maps with folium.

Plugins:

- https://github.com/onaci/folium-glify-layer: provide fast webgl rendering for large GeoJSON FeatureCollections
